@@ -208,6 +208,9 @@ QStringList Configuration::getNetworks()
     KConfig *conf= new KConfig(m_confFile,false,false,"config");
     if (!conf) return tmpList;
     tmpList = conf->groupList();
+    if (tmpList.isEmpty()) return tmpList;
+    if (*(tmpList.begin())==QString("<default>")) 
+        tmpList.pop_front();
     return tmpList;
 }
 
