@@ -72,10 +72,11 @@ void KProfileConfigDlg::dnsAddDomain()
     leDnsSearch->clear();
 }
 
+/*
 void KProfileConfigDlg::setMainWin( KwlanMainWin * mainWin )
 {
 }
-
+*/
 void KProfileConfigDlg::dhcpState(int state)
 {
     state = !state;
@@ -132,7 +133,7 @@ void KProfileConfigDlg::setInterface( KwlanInterface * interface )
         cbEncryption->setEnabled(FALSE);
         KMessageBox::setDontShowAskAgainConfig(mainConfiguration().m_configuration);
         KMessageBox::information(0,i18n("WPA Supplicant is not started, encryption cannot be configured"),0,"dontwarnnowpa");
-        KMessageBox::saveDontShowAgainContinue("dontwarnnowpa");
+        //KMessageBox::saveDontShowAgainContinue("dontwarnnowpa");
     }
 }
 
@@ -179,7 +180,7 @@ void KProfileConfigDlg::paramsFromConfig(KwlanInterface *interface, QString ssid
     int i, counter;
     QString ipaddress, netmask,gateway,dns1,dns2,domain;
     QStringList dnsSearchlist;
-    bool useDhcp, dontOverrideIp,dontOverrideDns, hidden;
+    bool useDhcp, dontOverrideIp,dontOverrideDns;
 
     m_editNetworkID = interface->getWpaId( ssid);
     if (m_editNetworkID==-1 ) m_newNetwork = TRUE;
@@ -193,7 +194,6 @@ void KProfileConfigDlg::paramsFromConfig(KwlanInterface *interface, QString ssid
     {
         snprintf(cmd, sizeof(cmd), "GET_NETWORK %d scan_ssid", m_editNetworkID);
         reply_len = sizeof(reply);
-        int scan = 0;
         if (interface->ctrlRequest(cmd, reply, &reply_len) >= 0) {
             reply[reply_len] = '\0';
             if (strstr(reply, "1"))
@@ -458,20 +458,20 @@ void KProfileConfigDlg::paramsFromScanResults(kwlNetwork p  )
     if (p.m_adhoc) rbAdhoc->setChecked(TRUE);
     QString flags = p.m_flags;
     int auth, encr = 0;
-    if (flags.find("[WPA2-EAP") >= 0)
+    if ((flags.find("WPA2") >= 0) && (flags.find("EAP") >= 0))
         auth = AUTH_WPA2_EAP;
-    else if (flags.find("[WPA-EAP") >= 0)
+    else if ((flags.find("WPA") >= 0) && (flags.find("EAP") >= 0))
         auth = AUTH_WPA_EAP;
-    else if (flags.find("[WPA2-PSK") >= 0)
+    else if ((flags.find("WPA2") >= 0) && (flags.find("PSK") >= 0))
         auth = AUTH_WPA2_PSK;
-    else if (flags.find("[WPA-PSK") >= 0)
+    else if ((flags.find("WPA") >= 0) && (flags.find("PSK") >= 0))
         auth = AUTH_WPA_PSK;
     else
         auth = AUTH_NONE;
     
-    if (flags.find("-CCMP") >= 0)
+    if (flags.find("CCMP") >= 0)
         encr = 1;
-    else if (flags.find("-TKIP") >= 0)
+    else if (flags.find("TKIP") >= 0)
         encr = 0;
     else if (flags.find("WEP") >= 0)
         encr = 1;
