@@ -46,7 +46,7 @@ public slots:
   /*$PUBLIC_SLOTS$*/
   virtual void          dnsRemoveDomain();
   virtual void          dnsAddDomain();
-  virtual void          setMainWin( KwlanMainWin * mainWin );
+  //virtual void          setMainWin( KwlanMainWin * mainWin );
   virtual void          dhcpState(int state);
   virtual void          browseForServerCertificate();
   virtual void          browseForPrivateKey();
