@@ -62,42 +62,51 @@ void KwlanApplication::init()
     if (::debugOutput) kdDebug() << "User uid is: " << uid << endl;
     pw = getpwuid (uid);
     bool ok = TRUE;
+    QString groupUser,fileUser;
     if (pw)
     {
         user = QString(pw->pw_name);
         if (::debugOutput) kdDebug() << "Your username is: " << user << endl;
-        grp = getgrnam("dip");
-        if (grp)
+        QFileInfo finfo(getPath("pppd"));
+        kdDebug() << "pppd Path "<< getPath("pppd") << endl;
+        groupUser = finfo.group();
+        fileUser = finfo.owner();
+        kdDebug() << "Group of pppd: " << groupUser << endl;
+        if (fileUser != QString(user))
         {
-            char **actuser = grp->gr_mem;
-            while (*actuser)
+            // test if user is a member of the group of pppd and if it is group executable
+            if (finfo.permission( QFileInfo::ExeGroup))
             {
-                groupusers.append(*actuser);
-                actuser++;
+                grp = getgrnam(groupUser.ascii());
+                if (grp)
+                {
+                    char **actuser = grp->gr_mem;
+                    while (*actuser)
+                    {
+                        groupusers.append(*actuser);
+                        actuser++;
+                    }
+                    if (groupusers.findIndex(user)==-1 )
+                    {
+                        ok = FALSE;
+                    }
+                }
+                else ok = FALSE;
             }
+            else ok = FALSE;
         }
-        else ok = FALSE;
     }
     else ok = FALSE;
-    if (!ok)
+    
+    dialupUser = ok;
+    if (!dialupUser )
     {
-        KMessageBox::sorry(0,i18n("Could not find out your username. Cannot determine your access rights."));
-    }
-    kdDebug() << "Groupuser: " << groupusers << endl;
-    QString dontShowAgain="nodialupuserwarning";
-    if (groupusers.findIndex(user)==-1 )
-    {
-        // User not member of dip group
+        // User not member of pppd group
+        QString dontShowAgain="nodialupuserwarning";
         if (KMessageBox::shouldBeShownContinue(dontShowAgain))
         {
-            KMessageBox::information(0,QString(i18n("You are not a member of the dialup (dip) group. Dialup networking will not work.")),"Kwlan",dontShowAgain);
-            KMessageBox::saveDontShowAgainContinue(dontShowAgain);
+            KMessageBox::information(0,QString(i18n("You do not have permissions to start pppd or pppd was not found. Dialup networking will not work.")).arg(groupUser),"Kwlan",dontShowAgain);
         }
-        dialupUser = FALSE;
-    }
-    else
-    {
-        dialupUser = TRUE;
     }
     // check for existing directory for dialup networking
     if (dialupUser)
