@@ -83,6 +83,7 @@ KwlanInterface::KwlanInterface(KwlanMainWin *mainWin)
     m_fdSock = -1;
     m_state = DISABLED;
     m_isScanning = FALSE;
+    m_isConfiguring = FALSE;
     KMessageBox::setDontShowAskAgainConfig(mainConfiguration().m_configuration);
     //get path to wpa_supplicant
     m_wpaPath = getPath("wpa_supplicant");
@@ -121,7 +122,6 @@ void KwlanInterface::init(QString interface)
     memset(&m_devInfo, 0, sizeof(m_devInfo));
     strcpy(m_devInfo.ifr_name, interface.latin1());
     m_confFile = QString("kwlanrc.") + interface;
-    m_configureInterface = mainConfiguration().readConfigureInterface( interface);
     // find out if we have a wireless interface
     m_controlInterface = strdup(interface.ascii());
     QStringList wirelessInterfaces = getInterfaces();
@@ -138,7 +138,7 @@ void KwlanInterface::init(QString interface)
         // show wizard
         newInterfaceWizard(interface);
     }
-    
+    m_configureInterface = mainConfiguration().readConfigureInterface( interface);
     QStringList binDirs;
     if (m_type == ETHERNET)
     {
@@ -467,7 +467,6 @@ QStringList KwlanInterface::listWpaProfiles()
         
 QStringList KwlanInterface::listNonWpaProfiles(QStringList wpaProfiles)
 {
-    bool encrypted;
     QStringList profiles;
     if (!m_configuration) return profiles;
     profiles = m_configuration->getNetworks();
@@ -483,11 +482,13 @@ QStringList KwlanInterface::listNonWpaProfiles(QStringList wpaProfiles)
             continue;
         }
             // Check whether the Network can be used without encryption
+        /*
         m_configuration->readEncryption(*it,encrypted);
         if (encrypted) {
             it = profiles.remove(it);
             continue;
         }
+        */
         it++;
     }
     //kdDebug() << profiles << endl;
@@ -582,14 +583,34 @@ bool KwlanInterface::profileActivateNonWpa(QString ssid)
 
 bool KwlanInterface::profileActivateWpa(QString ssid)
 {
+    if (m_isConfiguring) return TRUE;
         // select network using wpa_supplicant
     if (!m_wpaStarted) return FALSE;
     int ret;
     char reply[40], cmd[256];
     size_t reply_len = sizeof(reply);
+    m_ssid = ssid;
     int id = getWpaId(ssid);
     if (id == -1 ){
-        KMessageBox::sorry(0, i18n("Could not find network in wpa_supplicant\nconfiguration."));
+        // Seems to be a new network, so configure it.
+        m_isConfiguring = TRUE;
+        for (kwlNetworkList::iterator it = m_availableNetworks.begin();it != m_availableNetworks.end();it++)
+        {
+            if ((*it).m_ssid == ssid)
+            {
+                KProfileConfigDlg *nc = new KProfileConfigDlg();
+                if (nc == NULL)
+                    return FALSE;
+                nc->setInterface(this);
+                nc->paramsFromScanResults((*it));
+                kdDebug() << (*it).m_flags << endl;
+                nc->show();
+                nc->exec();
+                m_isConfiguring = FALSE;
+                return TRUE;
+            }
+        }
+        //KMessageBox::sorry(0, i18n("Could not find network in wpa_supplicant\nconfiguration."));
         return FALSE;
     }
     snprintf(cmd, sizeof(cmd), "DISCONNECT");
@@ -615,7 +636,6 @@ bool KwlanInterface::profileActivateWpa(QString ssid)
     // store in config
     if (m_configuration) m_configuration->writeLastSsid( ssid);
     // set ip data
-    m_ssid = ssid;
     getIpData();
     
     checkWpaConnection();
@@ -633,6 +653,45 @@ bool KwlanInterface::profileActivate(QString ssid)
         return profileActivateWpa(ssid);
     }
     else {
+        // check if wpa_supplicant is needed for the network
+        for (kwlNetworkList::iterator it = m_availableNetworks.begin();it != m_availableNetworks.end();it++)
+        {
+            if ((*it).m_ssid==ssid)
+            {
+                if ((*it).m_flags.contains("WPA") )
+                {
+                    int result = KMessageBox::questionYesNo(0,i18n("To activate this network, wpa_supplicant must be started. Do you want to start wpa_supplicant?"),
+                                              "Kwlan");
+                    if (result == KMessageBox::Yes)
+                    {
+                        KStartSupplicantDlg *startSupplicant = new KStartSupplicantDlg();
+                        QString driver;
+                        m_configuration->readDriver(driver);
+                        if (startSupplicant )
+                        {
+                            QString iface = QString(m_controlInterface);
+                            startSupplicant->setData(&iface,&driver);
+                            startSupplicant->show();
+                            startSupplicant->exec();
+                            QString wpa_supplicant;
+                            if (startSupplicant->m_start)
+                            {
+                                KwlanSuProcess *startWpa= new KwlanSuProcess(NULL,"Start WPA Supplicant");
+                                *startWpa << m_wpaPath << QString("-i%1").arg(QString(m_controlInterface)) << QString ("-D%1").arg(startSupplicant->getDriver()) << QString("-c")+ m_wpaConf << "-B";
+                                startWpa->setDescription(i18n("Start WPA Supplicant"));
+                                startWpa->start();
+                                m_configuration->writeDriver(startSupplicant->getDriver());
+                                m_ssid = ssid;
+                            }
+                            delete startSupplicant;
+                            m_networkChange = true;
+                            return true;
+                        }
+                    }
+                }
+            }
+        }
+
         // select network using iwconfig
         return profileActivateNonWpa(ssid);
     }
@@ -675,10 +734,7 @@ void KwlanInterface::releaseIpAddress()
     }
     m_releaseProcess->setDescription(i18n("Release IP address"));
     connect (m_releaseProcess, SIGNAL(processExited(KwlanSuProcess*)), this, SLOT(releaseProcessExited(KwlanSuProcess*)));
-    //m_releaseProcess->start(SuProcessBase::Block);
     m_releaseProcess->start();
-    //m_interfaceData.ipAddress="";
-    //emit ipChanged( QString(""));
 }
 
 void KwlanInterface::setDnsSettings()
@@ -711,7 +767,6 @@ void KwlanInterface::setDnsSettings()
         *setNetwork << ";";
         *setNetwork << getPath("chown") << "root:root" << "/etc/resolv.conf";
         setNetwork->setDescription(i18n("Set network settings"));
-        //setNetwork->start(SuProcessBase::Block);
         setNetwork->start();
     }
 }
@@ -732,7 +787,7 @@ void KwlanInterface::checkType()
 
 void KwlanInterface::getIpAddress()
 {
-    if ((m_type == PPP)||(m_ssid.isEmpty()) || !m_configureInterface) return;
+    if ((m_type == PPP)||(m_ssid.isEmpty()) || !m_configureInterface || m_isConfiguring) return;
     if (m_dhcpProcess) 
     {
         // We are already running
@@ -782,7 +837,6 @@ void KwlanInterface::processWpaMessage(char *message)
 {
     char *pos = message, *pos2;
     int priority = 2;
-    //kdDebug() << message << endl;
     if (*pos == '<') {
         /* skip priority */
         pos++;
@@ -811,8 +865,6 @@ void KwlanInterface::processWpaMessage(char *message)
         pos2 = pos;
         QString lastmsg = pos2;
         lastmsg.truncate(40);
-    //textLastMessage->setText(lastmsg);
-    //pingsToStatusUpdate = 0;
         m_networkChange = true;
     
         if (str_match(pos, WPA_CTRL_REQ))
@@ -877,9 +929,8 @@ void KwlanInterface::startWpa(QString driver)
     *startWpa << m_wpaPath << QString("-i%1").arg(QString(m_controlInterface)) << QString ("-D%1").arg(driver) << QString("-c") +m_wpaConf << "-B";
     startWpa->setDescription(i18n("Start WPA Supplicant"));
     startWpa->start();
-	//remember last interface driver
+    //remember last interface driver
     if (m_configuration) m_configuration->writeDriver(driver);
-    //emit (wpaStatusChanged(TRUE));
     emit (networksChanged());
 }
 
@@ -917,9 +968,9 @@ void KwlanInterface::profileAdded()
 
 void KwlanInterface::updateData()
 {
-    bool tmpAvailable = m_interfaceData.available;
+    //bool tmpAvailable = m_interfaceData.available;
     bool tmpUp = m_interfaceData.up;
-    bool tmpConnected = m_interfaceData.connected;
+    //bool tmpConnected = m_interfaceData.connected;
     FILE* flags_fp = fopen((m_sysClassPath+"flags").latin1(), "r");
     bool currentStatus;
     if (!flags_fp)
@@ -935,7 +986,6 @@ void KwlanInterface::updateData()
         fclose(flags_fp);
         currentStatus = IFF_UP & flags;
     }
-    //if (!currentStatus && m_interfaceData.up) { // interface down...
     if (!currentStatus) { // interface down...
         // Interface is down and was up before -> set status variables
         m_interfaceData.up = FALSE;
@@ -1000,8 +1050,6 @@ void KwlanInterface::updateData()
                 m_interfaceData.rxBytes = currentRxBytes;
             }
 
-            //m_interfaceData.incomingBytes = currentRxBytes - m_interfaceData.prevRxBytes;
-            //m_interfaceData.prevRxBytes = currentRxBytes;
             m_interfaceData.rxString = KIO::convertSize( m_interfaceData.rxBytes );
         
             unsigned long currentTxBytes = readInterfaceNumValue("statistics/tx_bytes");
@@ -1023,8 +1071,6 @@ void KwlanInterface::updateData()
                 m_interfaceData.txBytes = currentTxBytes;
             }
 
-            //m_interfaceData.outgoingBytes = currentTxBytes - m_interfaceData.prevTxBytes;
-            //m_interfaceData.prevTxBytes = currentTxBytes;
             m_interfaceData.txString = KIO::convertSize( m_interfaceData.txBytes );
 
             m_interfaceData.rxPackets = readInterfaceNumValue("statistics/rx_packets");
@@ -1081,8 +1127,6 @@ void KwlanInterface::updateData()
             }
         }
     }
-    //if (tmpAvailable != m_interfaceData.available) 
-    //    emit (connectionStatusChanged (m_interfaceData.available));
     if (tmpUp != m_interfaceData.up)
     {
         emit (interfaceUp(m_interfaceData.up ));
@@ -1128,208 +1172,6 @@ void KwlanInterface::releaseProcessExited(KwlanSuProcess *process)
     }
 }
 
-void KwlanInterface::iwconfigProcessExited( KProcess* process )
-{
-    if ( process == m_iwconfigProcess )
-    {
-        delete m_iwconfigProcess;
-        m_iwconfigProcess = 0L;
-        parseIwconfigOutput();
-    }
-}
-
-void KwlanInterface::iwconfigProcessStdout( KProcess*, char* buffer, int buflen )
-{
-    m_iwconfigStdout += QString::fromLatin1( buffer, buflen );
-}
-
-void KwlanInterface::parseIwconfigOutput()
-{
-    /* mIwconfigStdout contains the complete output of 'iwconfig' which we
-    * are going to parse here.
-    */
-    QMap<QString, QString> configs;
-    QStringList ifList = QStringList::split( "\n\n", m_iwconfigStdout );
-    QStringList::Iterator it;
-    QString key;
-    for ( it = ifList.begin(); it != ifList.end(); ++it )
-    {
-        int index = ( *it ).find( ' ' );
-        if ( index == -1 )
-            continue;
-        key = ( *it ).left( index );
-        configs[key] = ( *it ).mid( index );
-    }
-    if ( configs.find( m_controlInterface) == configs.end() )
-    {
-        // The interface does not exist. Meaning the driver
-        // isn't loaded and/or the interface has not been created.
-        m_interfaceData.existing = false;
-        m_interfaceData.available = false;
-    }
-
-    if ( configs[m_controlInterface].contains( "no wireless extensions" ) )
-    {
-        // The interface isn't a wireless device.
-        m_interfaceData.wirelessDevice = false;
-    }
-    else
-    {
-        // Update the wireless data of the interface.
-        m_interfaceData.wirelessDevice = true;
-        updateWirelessData( configs[m_controlInterface] );
-    }
-}
-
-void KwlanInterface::updateWirelessData( QString& config )
-{
-    QRegExp regExp( "radio off" );
-    if ( regExp.search( config ) > -1 ) {
-        m_wirelessData.radioOff = TRUE;
-        return; //The rest of the information isn't needed when radio is off.
-    } else
-        m_wirelessData.radioOff = FALSE;
-
-    regExp.setPattern( "ESSID:\"?([^\"]*)\"?" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.essid = regExp.cap( 1 );
-
-    regExp.setPattern( "Mode:(\\w*)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.mode = regExp.cap( 1 );
-
-    regExp.setPattern( "Frequency:([\\w|\\.]*)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.frequency = regExp.cap( 1 );
-    else
-    {
-        regExp.setPattern( "Channel:(\\d*)" );
-        if ( regExp.search( config ) > -1 )
-            m_wirelessData.channel = regExp.cap( 1 );
-    }
-
-    regExp.setPattern( "Bit Rate[=:]([\\w/]*)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.bitRate = regExp.cap( 1 );
-
-    regExp.setPattern( "Signal level.(-?\\d+\\s*\\w+)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.signal = regExp.cap( 1 );
-
-    regExp.setPattern( "Noise level.(-?\\d+\\s*\\w+)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.noise = regExp.cap( 1 );
-
-    regExp.setPattern( "Link Quality[=:]([\\d/]*)" );
-    if ( regExp.search( config ) > -1 )
-        m_wirelessData.linkQuality = regExp.cap( 1 );
-}
-
-void KwlanInterface::updateInterfaceData( QString& config, int type )
-{
-    bool hasIpAddress = TRUE;
-    if (m_interfaceData.ipAddress.isEmpty()) hasIpAddress = FALSE;
-    QRegExp regExp( ".*RX.*:(\\d+).*:\\d+.*:\\d+.*:\\d+" );
-    if ( regExp.search( config ) > -1 )
-        m_interfaceData.rxPackets = regExp.cap( 1 ).toULong();
-
-    regExp.setPattern( ".*TX.*:(\\d+).*:\\d+.*:\\d+.*:\\d+" );
-    if ( regExp.search( config ) > -1 )
-        m_interfaceData.txPackets = regExp.cap( 1 ).toULong();
-
-    regExp.setPattern( "RX bytes:(\\d+)\\s*\\(\\d+\\.\\d+\\s*\\w+\\)" );
-    if ( regExp.search( config ) > -1 )
-    {
-        // We count the traffic on ourself to avoid an overflow after
-        // 4GB of traffic.
-        unsigned long currentRxBytes = regExp.cap( 1 ).toULong();
-        if ( currentRxBytes < m_interfaceData.prevRxBytes )
-        {
-            // there was an overflow
-            m_interfaceData.rxBytes = currentRxBytes;
-            m_interfaceData.prevRxBytes = 0L;
-        }
-        if ( m_interfaceData.rxBytes == 0L )
-        {
-            // on startup set to currently received bytes
-            m_interfaceData.rxBytes = currentRxBytes;
-            m_interfaceData.prevRxBytes = currentRxBytes;
-        }
-        else
-            // afterwards only add difference to previous number of bytes
-        {
-            m_interfaceData.prevRxBytes = m_interfaceData.rxBytes;
-            m_interfaceData.rxBytes = currentRxBytes;
-        }
-
-            //m_interfaceData.incomingBytes = currentRxBytes - m_interfaceData.prevRxBytes;
-            //m_interfaceData.prevRxBytes = currentRxBytes;
-        m_interfaceData.rxString = KIO::convertSize( m_interfaceData.rxBytes );
-    }
-
-
-    regExp.setPattern( "TX bytes:(\\d+)\\s*\\(\\d+\\.\\d+\\s*\\w+\\)" );
-    if ( regExp.search( config ) > -1 )
-    {
-        // We count the traffic on ourself to avoid an overflow after
-        // 4GB of traffic.
-        unsigned long currentTxBytes = regExp.cap( 1 ).toULong();
-        if ( currentTxBytes < m_interfaceData.prevTxBytes )
-        {
-            // there was an overflow
-            m_interfaceData.txBytes = currentTxBytes;
-            m_interfaceData.prevTxBytes = 0L;
-        }
-        if ( m_interfaceData.txBytes == 0L )
-        {
-            // on startup set to currently transmitted bytes
-            m_interfaceData.txBytes = currentTxBytes;
-            m_interfaceData.prevTxBytes = currentTxBytes;
-        }
-        else
-        {
-            m_interfaceData.prevTxBytes = m_interfaceData.txBytes;
-            m_interfaceData.txBytes = currentTxBytes;
-        }
-
-            //m_interfaceData.outgoingBytes = currentTxBytes - m_interfaceData.prevTxBytes;
-            //m_interfaceData.prevTxBytes = currentTxBytes;
-        m_interfaceData.txString = KIO::convertSize( m_interfaceData.txBytes );
-    }
-  
-
-    regExp.setPattern( "inet\\s+\\w+:(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3})" );
-    if ( regExp.search( config ) > -1 )
-    {
-        m_interfaceData.ipAddress = regExp.cap( 1 );
-        //if (!hasIpAddress) startScriptAfterConnect();
-    }
-    else m_interfaceData.ipAddress = "";
-    regExp.setPattern( "(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}).*(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}).*(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3})" );
-    if ( regExp.search( config ) > -1 )
-    {
-        m_interfaceData.broadcastAddress = regExp.cap( 2 );
-        m_interfaceData.subnetMask = regExp.cap( 3 );
-    }
-    else {
-        m_interfaceData.broadcastAddress = "";
-        m_interfaceData.subnetMask = "";
-    }
-    
-
-    if ( type == ETHERNET )
-    {
-        regExp.setPattern( "(.{2}:.{2}:.{2}:.{2}:.{2}:.{2})" );
-        if ( regExp.search( config ) > -1 )
-            m_interfaceData.hwAddress = regExp.cap( 1 );
-    }
-    else if (  type == PPP )
-    {
-        regExp.setPattern( "(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}).*(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}).*(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3})" );
-        if ( regExp.search( config ) > -1 )
-            m_interfaceData.ptpAddress = regExp.cap( 2 );
-    }
-}
 
 void KwlanInterface::logViewer()
 {
@@ -1511,7 +1353,6 @@ void KwlanInterface::newInterfaceWizard(QString interface)
 {
     int res = KMessageBox::warningContinueCancel(0,QString(i18n("New interface found!\n%1\n Click Continue to configure it now.")).arg(interface),"Kwlan",
             KStdGuiItem::cont(),"newinterfacewizard");
-    KMessageBox::saveDontShowAgainContinue("newinterfacewizard");
     if (res == KMessageBox::Continue)
     {
         //User wants to configure interface
