@@ -175,8 +175,8 @@ class KwlanInterface  : public QObject
         void stopWpa();
         QString getInterfaceName();
         void profileAdded();
-        void iwconfigProcessExited( KProcess* process );
-        void iwconfigProcessStdout( KProcess*, char* buffer, int buflen );
+        //void iwconfigProcessExited( KProcess* process );
+        //void iwconfigProcessStdout( KProcess*, char* buffer, int buflen );
         void dhcpProcessExited(KwlanSuProcess *);
         void releaseProcessExited(KwlanSuProcess *);
         //void iwconfigProcessExited( KProcess* process );
@@ -220,6 +220,7 @@ class KwlanInterface  : public QObject
         bool m_ipConfigured;
         bool m_configureInterface;
         bool m_isScanning;
+        bool m_isConfiguring;
         QString m_ssid;
         QString m_staticIpAddress,  m_staticGateway, m_staticNetmask;
         QString m_staticDns1, m_staticDns2, m_domain;
@@ -253,7 +254,7 @@ class KwlanInterface  : public QObject
         kwlNetworkList m_availableNetworks;
         
         void parseIwconfigOutput();
-        void updateInterfaceData( QString& config,  int type );
+        //void updateInterfaceData( QString& config,  int type );
         void updateWirelessData( QString& config );
         void getIpData();
         unsigned long readInterfaceNumValue(const char *name);
