@@ -1,12 +1,25 @@
+/*
+   
+        (c) 2006 by Thomas Michel <tom.michel@arcor.de>
+
+        Kwlan is free software; you can redistribute it and/or modify
+        it under the terms of the GNU Library General Public License as
+        published by the Free Software Foundation; either version 2 of
+        the License, or (at your option) any later version.
+
+        Kwlan is distributed in the hope that it will be useful,
+        but WITHOUT ANY WARRANTY; without even the implied warranty of
+        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+        GNU Library General Public License for more details.
+
+        You should have received a copy of the GNU Library General Public License
+        along with this library; see the file COPYING.LIB.  If not, write to
+        the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+        Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __KWLANMAINTRAYWIN__
 #define  __KWLANMAINTRAYWIN__
-/** Kwlan
- *
- *  This File is part of Kwlan, a network Manager for KDE.
- *  Kwlan is distributed under LGPL license.
- *
- *	@author Thomas Michel <tom.michel@arcor.de>
- */
 
 #include <ksystemtray.h>
 #include <qtooltip.h>
